aboutsummaryrefslogtreecommitdiff
path: root/runtime/tools
diff options
context:
space:
mode:
authorAlp Toker <alp@nuanti.com>2014-02-24 10:40:15 +0000
committerAlp Toker <alp@nuanti.com>2014-02-24 10:40:15 +0000
commit4bf04f627e8005bc19be5ced4eb6ca8fe1812559 (patch)
tree26b2c681dd5d1548b775417b40ab477e57746c15 /runtime/tools
parent024c10806dc0b61950f0d094da1658d09f3e1b38 (diff)
Fix typos
git-svn-id: https://llvm.org/svn/llvm-project/openmp/trunk@202018 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'runtime/tools')
-rwxr-xr-xruntime/tools/expand-vars.pl2
-rwxr-xr-xruntime/tools/generate-def.pl4
-rw-r--r--runtime/tools/lib/Uname.pm12
-rw-r--r--runtime/tools/lib/tools.pm6
-rwxr-xr-xruntime/tools/required-objects.pl6
-rwxr-xr-xruntime/tools/wipe-string.pl2
6 files changed, 16 insertions, 16 deletions
diff --git a/runtime/tools/expand-vars.pl b/runtime/tools/expand-vars.pl
index 57a3ec9..40a6490 100755
--- a/runtime/tools/expand-vars.pl
+++ b/runtime/tools/expand-vars.pl
@@ -262,7 +262,7 @@ variable before use. See examples.
=head1 EXAMPLES
-Replace occurences of C<$year>, C<$month>, and C<$day> in C<input.txt> file with C<2007>, C<09>, C<01>
+Replace occurrences of C<$year>, C<$month>, and C<$day> in C<input.txt> file with C<2007>, C<09>, C<01>
respectively and write result to C<output.txt> file:
$ cat input.var
diff --git a/runtime/tools/generate-def.pl b/runtime/tools/generate-def.pl
index 1ebc424..7c2b0f3 100755
--- a/runtime/tools/generate-def.pl
+++ b/runtime/tools/generate-def.pl
@@ -216,7 +216,7 @@ B<generate-def.pl> I<OPTION>... I<file>
=item B<-D> I<name>[=I<value>]
-Define specified name. If I<value> is ommitted, I<name> is defined to 1. If I<value> is 0 or empty,
+Define specified name. If I<value> is omitted, I<name> is defined to 1. If I<value> is 0 or empty,
name is B<not> defined.
=item B<--output=>I<file>
@@ -284,7 +284,7 @@ Comments start with C<#> symbol and continue to the end of line.
%ifndef name
%endif
-A part of file surronded by C<%ifdef I<name>> and C<%endif> directives is a conditional part -- it
+A part of file surrounded by C<%ifdef I<name>> and C<%endif> directives is a conditional part -- it
has effect only if I<name> is defined in the comman line by B<--define> option. C<%ifndef> is a
negated version of C<%ifdef> -- conditional part has an effect only if I<name> is B<not> defined.
diff --git a/runtime/tools/lib/tools.pm b/runtime/tools/lib/tools.pm
index 23feb50..ce5cf44 100644
--- a/runtime/tools/lib/tools.pm
+++ b/runtime/tools/lib/tools.pm
@@ -544,7 +544,7 @@ sub question($;\$$) {
my $a = ( defined( $answer ) ? $$answer : undef );
if ( ref( $choices ) eq "Regexp" ) {
- # It is aready a regular expression, do nothing.
+ # It is already a regular expression, do nothing.
} elsif ( defined( $choices ) ) {
# Convert string to a regular expression.
$choices = qr/[@{ [ quotemeta( $choices ) ] }]/i;
@@ -705,7 +705,7 @@ Look for all occurenses of "cp" in the PATH:
my @cps = which( "cp", -all => 1 );
-Look for the first occurence of "icc" in the specified directories:
+Look for the first occurrence of "icc" in the specified directories:
my $icc = which( "icc", -dirs => [ ".", "/usr/local/bin", "/usr/bin", "/bin" ] );
@@ -1163,7 +1163,7 @@ sub del_dir($@) {
Change current directory.
-If any error occured, error issues and script exits.
+If any error occurred, error issues and script exits.
=cut
diff --git a/runtime/tools/required-objects.pl b/runtime/tools/required-objects.pl
index c5d75b0..b378b08 100755
--- a/runtime/tools/required-objects.pl
+++ b/runtime/tools/required-objects.pl
@@ -92,12 +92,12 @@ sub dump_symbols($$$) {
# --------------------------------------------------------------------------------------------------
# Name:
-# load_symbols -- Fullfill objects data structure with symbol names.
+# load_symbols -- Fulfill objects data structure with symbol names.
# Synopsis:
# load_symbols( $objects );
# Arguments:
# $objects (in/out) -- Set of objects. On enter, it is expected that top-level hash has filled
-# with object names only. On exit, it is completely fullfilled with lists of symbols
+# with object names only. On exit, it is completely fulfilled with lists of symbols
# defined or referenced in each object file.
# Returns:
# Nothing.
@@ -333,7 +333,7 @@ sub _required_extra_objects($$$$) {
# Arguments:
# $base (in/out) -- A set of base objects to be searched for undefined symbols. On enter, it is
# expected that top-level hash has filled with object names only. On exit, it is completely
-# fullfilled with lists of symbols defined and/or referenced in each object file.
+# fulfilled with lists of symbols defined and/or referenced in each object file.
# $extra (in/out) -- A set of extra objects to be searched for defined symbols required to
# resolve undefined symbols in a set of base objects. Usage is similar to base objects.
# Returns:
diff --git a/runtime/tools/wipe-string.pl b/runtime/tools/wipe-string.pl
index 3d879c8..deab95f 100755
--- a/runtime/tools/wipe-string.pl
+++ b/runtime/tools/wipe-string.pl
@@ -176,7 +176,7 @@ Wipe "defaultlib" directive in all the library files:
wipe-string.pl --wipe-regexp="-defaultlib:[A-Za-z0-9_.]+" *.lib
(Be careful: the script does not analyze structure of library and object files, it just wipes
-U<strings>, so it wipes all the occurences of strings matching to specified regular expression.)
+U<strings>, so it wipes all the occurrences of strings matching to specified regular expression.)
=cut
diff --git a/runtime/tools/lib/Uname.pm b/runtime/tools/lib/Uname.pm
index 9556884..4eb6991 100644
--- a/runtime/tools/lib/Uname.pm
+++ b/runtime/tools/lib/Uname.pm
@@ -58,7 +58,7 @@ my @aux =
qw{ host_name domain_name },
map( "operating_system_$_", qw{ name release codename description } )
);
- # Auxillary properties.
+ # Auxiliary properties.
my @all = ( @base, @aux );
# All the properties.
my @meta = qw{ base_names all_names value };
@@ -209,7 +209,7 @@ if ( 0 ) {
if ( 0 ) {
} elsif ( $values{ kernel_name } eq "Linux" ) {
$values{ operating_system } = "GNU/Linux";
- my $release; # Name of choosen "*-release" file.
+ my $release; # Name of chosen "*-release" file.
my $bulk; # Content of release file.
# On Ubuntu, lsb-release is quite informative, e. g.:
# DISTRIB_ID=Ubuntu
@@ -454,7 +454,7 @@ C</bin/uname> and C<POSIX::uname()>.
$hardware_platform = Uname::hardware_platform();
$operating_system = Uname::operating_system();
# Auxillary property functions.
$host_name = Uname::host_name();
$domain_name = Uname::domain_name();
$os_name = Uname::operating_system_name();
@@ -547,11 +547,11 @@ One of: C<GNU/Linux>, C<OS X*>, or C<MS Windows>.
=back
-=head2 Auxillary Functions
+=head2 Auxiliary Functions
-Auxillary functions extends base functions with information not reported by C<uname> program.
+Auxiliary functions extends base functions with information not reported by C<uname> program.
-Auxillary functions collect information from different sources. For example, on OS X*, they may
+Auxiliary functions collect information from different sources. For example, on OS X*, they may
call C<sw_vers> program to find out OS release; on Linux* OS they may parse C</etc/redhat-release> file,
etc.
@@ -454,7 +454,7 @@ C</bin/uname> and C<POSIX::uname()>.
$hardware_platform = Uname::hardware_platform();
$operating_system = Uname::operating_system();
- # Auxillary property functions.
+ # Auxiliary property functions.
$host_name = Uname::host_name();
$domain_name = Uname::domain_name();